@@ -30,25 +30,25 @@ class RemoteTableDataStore(RemoteStore):
         """ """
         return self.ref
 
-    def get_table_df(self, table: str):
+    def get_parent_df(self, parent: str):
         """
 
         Args:
-          table: str:
+          parent (str): The parent taxon (/ is root)
 
         Returns:
 
         """
         import pandas as pd
 
-        table_result = self.get_table(table)
+        table_result = self.get_parent(parent)
         return pd.DataFrame(table_result['rows'], columns=table_result['columns'])
 
-    def get_table(self, table: str):
+    def get_parent(self, parent: str):
         """
 
         Args:
-          table: str:
+          parent (str): The parent taxon (/ is root)
 
         Returns:
 
@@ -56,14 +56,14 @@ class RemoteTableDataStore(RemoteStore):
 
         # We need to get the first set of rows,
         rows: List = []
-        row_response = self.get_table_page_request(table, 1)
+        row_response = self.get_parent_page_request(parent, 1)
 
         # lets work out the last page
         rows = rows + row_response['content']
         total_pages = row_response['totalPages']
 
         for page in range(2, total_pages):
-            row_response = self.get_table_page_request(table, page)
+            row_response = self.get_parent_page_request(parent, page)
             rows = rows + row_response['content']
 
         # Once we have all the rows we will then get a list of all the columns
@@ -91,13 +91,13 @@ class RemoteTableDataStore(RemoteStore):
             "rows": new_rows
         }
 
-    def get_table_page_request(self, table: str, page_number: int = 1, page_size=5000):
+    def get_parent_page_request(self, parent: str, page_number: int = 1, page_size=5000):
         """
 
         Args:
-          table: str:
-          page_number: int:  (Default value = 1)
-          page_size:  (Default value = 5000)
+          parent (str): The parent taxon (/ is root)
+          page_number (int):  (Default value = 1)
+          page_size (int):  (Default value = 5000)
 
         Returns:
 
@@ -110,7 +110,7 @@ class RemoteTableDataStore(RemoteStore):
         # We need to go through and pull all the pages
         rows_response = requests.get(
             url,
-            params={"table": table, "page": page_number, "pageSize": page_size},
+            params={"parent": parent, "page": page_number, "pageSize": page_size},
             headers={"x-access-token": KodexaPlatform.get_access_token(), "content-type": "application/json"})
 
         if rows_response.status_code == 200:
@@ -377,6 +377,30 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
         else:
             return []
 
+    def replace_content_object(self, document_family: DocumentFamily, content_object_id: str,
+                               document: Document) -> DocumentFamily:
+        from kodexa import KodexaPlatform
+        try:
+            logger.info(f"Replacing document in family {document_family.id} content object {content_object_id}")
+
+            files = {"document": document.to_msgpack()}
+            content_object_replace = requests.put(
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/families/{document_family.id}/objects/{content_object_id}/content",
+                headers={"x-access-token": KodexaPlatform.get_access_token()},
+                files=files)
+
+            if content_object_replace.status_code == 200:
+                return DocumentFamily.from_dict(content_object_replace.json())
+            else:
+                msg = "Document replace failed [" + content_object_replace.text + "], response " + str(
+                    content_object_replace.status_code)
+                logger.error(msg)
+                raise Exception(msg)
+        except JSONDecodeError:
+            logger.error(
+                "Unable to decode the JSON response")
+            raise
+
     def put(self, path: str, document: Document, force_replace: bool = False) -> DocumentFamily:
         from kodexa import KodexaPlatform
         try:
@@ -401,6 +425,30 @@ class RemoteDocumentStore(DocumentStore, RemoteStore):
                 "Unable to decode the JSON response")
             raise
 
+    def put_native(self, path: str, content, force_replace: bool = False) -> DocumentFamily:
+        from kodexa import KodexaPlatform
+        try:
+            logger.info(f"Putting native content to path {path}")
+
+            files = {"file": content}
+            data = {"path": path, "forceReplace": force_replace}
+            document_family_response = requests.post(
+                f"{KodexaPlatform.get_url()}/api/stores/{self.ref.replace(':', '/')}/fs/{path}",
+                headers={"x-access-token": KodexaPlatform.get_access_token()},
+                files=files, data=data)
+
+            if document_family_response.status_code == 200:
+                return DocumentFamily.from_dict(document_family_response.json())
+            else:
+                msg = "Document family create failed [" + document_family_response.text + "], response " + str(
+                    document_family_response.status_code)
+                logger.error(msg)
+                raise Exception(msg)
+        except JSONDecodeError:
+            logger.error(
+                "Unable to decode the JSON response")
+            raise
+
     def get_family_by_path(self, path: str) -> Optional[DocumentFamily]:
         get_response = self._base_get(f"api/stores/{self.ref.replace(':', '/')}/fs/{path}", params={"meta": True})
         return DocumentFamily.from_dict(get_response.json()) if get_response is not None else None
